/*
 * Pop that popup up on the page.
 */
(function ($, Drupal, window, document, undefined) {
  function setCookie(cname, cvalue, exhours) {
    var d = new Date();
    d.setTime(d.getTime() + (exhours*60*60*1000));
    var expires = "expires="+d.toUTCString();
    document.cookie = cname + "=" + cvalue + "; " + expires;
  }

  function getCookie(cname) {
      var name = cname + "=";
      var ca = document.cookie.split(';');
      for(var i=0; i<ca.length; i++) {
          var c = ca[i];
          while (c.charAt(0)==' ') c = c.substring(1);
          if (c.indexOf(name) != -1) return c.substring(name.length,c.length);
      }
      return "";
  }

  function deleteCookie(cname) {
    var d = new Date();
    d.setTime(1);
    var expires = "expires="+d.toUTCString();
    document.cookie = cname + "=; " + expires;
  }

  /*
   * Show the popup if the cookie doesn't match the timestamp in the db
   */
  function showPopup(dbStamp, cookieExpiration, startDateUtc, endDateUtc) {
    var lastShown = getCookie('blockpop_popup_last_shown');
    var show = true;
    var now = new Date().getTime();
    now = Math.round(now / 1000);
    var start = new Date();
    start.setTime(startDateUtc * 1000);
    if (startDateUtc != null && now < startDateUtc) {
      show = false;
    }
    if (endDateUtc != null && now > endDateUtc ) {
      show = false;
    }
    if (lastShown == dbStamp && cookieExpiration != 'always') {
      show = false;
    }
    return show;
  }

  Drupal.behaviors.blockPopPopupBehavior = {
    "attach": function(context, settings) {
      var $popup = $('#block-blockpop-popup', context);

      function resizePopup() {
        //document.body.clientWidth is width without scrollbar
        if (document.body.clientWidth < width) {
          $popup.width(document.body.clientWidth - 20 - parseInt(settings.blockpop.padding));
        }
        $.modal.resize();
      }

      if (!!settings.blockpop) {
        var dbStamp = settings.blockpop.timestamp;
        if ($popup.length && showPopup(dbStamp, settings.blockpop.cookieExpiration,  settings.blockpop.startDateUtc, settings.blockpop.endDateUtc)) {
          if (!$popup.hasClass('blockpop-popup-processed')) {
            var width = parseInt(settings.blockpop.width);
            var marginLeft = Math.floor(width / 2) * -1;
            $popup.addClass('blockpop-popup-processed').addClass('modal')
              .width(width)
              .css('border-radius', settings.blockpop.borderRadius + 'px')
              .css('padding', settings.blockpop.padding + 'px');
            if (!!settings.blockpop.popupStyle) {
              $popup.addClass(settings.blockpop.popupStyle);
            }
            $popup.modal({
              "zIndex": parseInt(settings.blockpop.zIndex) - 1
            });
            $popup.find('.content a').click(function(event) {
              if (!!window._gaq || !!window.ga) {
                var $this = $(this);
                var gaEventCategory = settings.blockpop.gaEventCategory ? settings.blockpop.gaEventCategory : null;
                var gaEventAction = settings.blockpop.gaEventAction ? settings.blockpop.gaEventAction : null;
                var href = $this.attr('href');
                if (!!href) {
                  if ($this.data('gaEventCategory') && $this.data('gaEventAction')) {
                    gaEventCategory = $this.data('gaEventCategory');
                    gaEventAction = $this.data('gaEventAction');
                  }
                  // Classic Analytics ga.js
                  if (!!window._gaq && gaEventCategory && gaEventAction) {
                    event.preventDefault();
                    _gaq.push(['_set', 'hitCallback', function() {
                        document.location = href;
                    }]);
                    _gaq.push(['_trackEvent', gaEventCategory, gaEventAction]);
                    return false;
                  }
                  // Universal Analytics analytics.js
                  if (!!window.ga && gaEventCategory && gaEventAction) {
                    event.preventDefault();
                    ga('send', 'event', gaEventCategory, gaEventAction, {
                      "useBeacon": true,
                      "hitCallback": function(){
                        document.location = href;
                      }
                    });
                    return false;
                  }
                }
              }
            });

            var expirationHours = parseInt(settings.blockpop.cookieExpirationHours);
            setCookie('blockpop_popup_last_shown', dbStamp, expirationHours);
            $popup.find('img').load(function(){
              resizePopup();
            });
            $(window).load(function(){
              resizePopup();
            }).resize(function(){
              resizePopup();
            });
          }
        }
      }
    }
  };
})(jQuery, Drupal, this, this.document);
